==> tidyfinance_0.3.0.tar.gz: tidyfinance/R/global_variables.R <==
# Set global variables ------------------------------------------------
utils::globalVariables(
  c(
    "date", "rp_div", "dp", "dy", "ep", "de", "svar", "bm", "b/m", "ntis", "tbl", "lty", "ltr",
    "tms", "dfy", "infl", "AAA", "BAA", "D12", "DATE", "E12", "Index", "IndexDiv", "Rfree",
    "mkt-rf", "mkt_excess", "rf", "year", "month", "f", "mkt", "yyyymm", "yyyyq", "quarter",
    "yyyy", "logret",
    "altprc", "at", "at_lag", "be", "capx", "ceq", "cogs", "consol",
    "datadate", "datafmt", "dlret",
    "dlstcd", "dlstdt", "exchcd", "gvkey", "indfmt", "inv", "itcb", "linkdt", "linkenddt",
    "lpermno", "lt", "mktcap", "namedt", "nameendt", "oancf", "permno", "pstk", "pstkl", "pstkrv", "ret",
    "ret_adj", "ret_excess", "risk_free", "sale", "shrcd", "shrout", "siccd", "txdb", "txditc", "xint",
    "xsga","ret_excess",
    "dlycaldt", "dlyret", "issuertype", "mthcaldt", "calculation_date", "mthprc", "mthret", "prc", "primaryexch",
    "secinfoenddt", "secinfostartdt", "securitysubtype", "securitytype", "sharetype",
    "usincflg", "hml", "smb",
    "issuer_id", "sic_code", "country_domicile",
    "complete_cusip", "maturity", "offering_amt", "offering_date",
    "dated_date", "interest_frequency", "coupon", "last_interest_date",
    "issue_id", "security_level", "slob", "security_pledge", "asset_backed",
    "defeased", "defeased_date", "bond_type", "pay_in_kind","pay_in_kind_exp_date",
    "yankee", "canadian", "foreign_currency", "coupon_type", "fix_frequency",
    "coupon_change_indicator", "interest_frequency", "rule_144a",
    "private_placement", "defaulted", "filing_date", "settlement",
    "convertible", "exchange", "putable", "unit_deal", "exchangeable",
    "perpetual", "preferred_security",
    "cusip_id", "trd_exctn_dt", "trd_exctn_tm",
    "rptd_pr", "entrd_vol_qt", "yld_pt", "rpt_side_cd", "cntra_mp_id",
    "asof_cd", "days_to_sttl_ct", "days_to_sttl_ct2", "msg_seq_nb", "orig_msg_seq_nb",
    "pr_trd_dt", "spcl_trd_fl", "stlmnt_dt", "trc_st", "trd_rpt_dt", "trd_rpt_tm", "wis_fl",
    "conditionaltype", "tradingstatusflg",
    "log_d12", "log_e12",
    "rdq", "fqtr", "fyearq", "atq", "ceqq"
  )
)

==> tidyfinance_0.4.0.tar.gz: tidyfinance/R/global_variables.R <==
# Set global variables ------------------------------------------------
utils::globalVariables(
  c(
    "date", "rp_div", "dp", "dy", "ep", "de", "svar", "bm", "b.m", "ntis", "tbl", "lty", "ltr",
    "tms", "dfy", "infl", "AAA", "BAA", "D12", "DATE", "E12", "Index", "IndexDiv", "Rfree",
    "mkt-rf", "mkt_excess", "rf", "year", "month", "f", "mkt", "yyyymm", "yyyyq", "quarter",
    "yyyy", "logret",
    "altprc", "at", "at_lag", "be", "capx", "ceq", "cogs", "consol",
    "datadate", "datafmt", "dlret",
    "dlstcd", "dlstdt", "exchcd", "gvkey", "indfmt", "inv", "itcb", "linkdt", "linkenddt",
    "lpermno", "lt", "mktcap", "namedt", "nameendt", "oancf", "permno", "pstk", "pstkl", "pstkrv", "ret",
    "ret_adj", "ret_excess", "risk_free", "sale", "shrcd", "shrout", "siccd", "txdb", "txditc", "xint",
    "xsga","ret_excess",
    "dlycaldt", "dlyret", "issuertype", "mthcaldt", "calculation_date", "mthprc", "mthret", "prc", "primaryexch",
    "secinfoenddt", "secinfostartdt", "securitysubtype", "securitytype", "sharetype",
    "usincflg", "hml", "smb",
    "issuer_id", "sic_code", "country_domicile",
    "complete_cusip", "maturity", "offering_amt", "offering_date",
    "dated_date", "interest_frequency", "coupon", "last_interest_date",
    "issue_id", "security_level", "slob", "security_pledge", "asset_backed",
    "defeased", "defeased_date", "bond_type", "pay_in_kind","pay_in_kind_exp_date",
    "yankee", "canadian", "foreign_currency", "coupon_type", "fix_frequency",
    "coupon_change_indicator", "interest_frequency", "rule_144a",
    "private_placement", "defaulted", "filing_date", "settlement",
    "convertible", "exchange", "putable", "unit_deal", "exchangeable",
    "perpetual", "preferred_security",
    "cusip_id", "trd_exctn_dt", "trd_exctn_tm",
    "rptd_pr", "entrd_vol_qt", "yld_pt", "rpt_side_cd", "cntra_mp_id",
    "asof_cd", "days_to_sttl_ct", "days_to_sttl_ct2", "msg_seq_nb", "orig_msg_seq_nb",
    "pr_trd_dt", "spcl_trd_fl", "stlmnt_dt", "trc_st", "trd_rpt_dt", "trd_rpt_tm", "wis_fl",
    "conditionaltype", "tradingstatusflg",
    "log_d12", "log_e12",
    "rdq", "fqtr", "fyearq", "atq", "ceqq",
    "beta_date", "estimates", "name", "risk_premium", "row_check",
    "standard_error", "t_statistic", "value",
    "VALUE",
    "bottom", "closest", "long_short_return", "lower_bound", "mktcap_lag",
    "portfolio", "portfolio_main", "portfolio_secondary", "ret_excess_ew",
    "ret_excess_vw", "ret_measure", "top", "upper_bound",
    "Anlageklasse", "Asset.Class", "symbol",
    "country", "industry", "ipoyear", "sector",
    "..date", "..id"
  )
)
